<no title> — The Research Software Encyclopedia 11 documentation

# CHANGELOG

This is a manually generated log to track changes to the repository for each release. Each section should include general headers such as Implemented enhancements and Merged pull requests. Critical items to know are:

> - renamed commands

> - deprecated / removed commands

> - changed defaults

> - backward incompatible changes

> - migration guidance

> - changed behaviour

The versions coincide with releases on pip.

## [0.0.x](https://github.com/rseng/rse/tree/master) (0.0.x)

  - ipython should not be required for shell (0.0.31)

  - updating annotation interface to be better searched (0.0.30)

  - adding topics to GitHub request (0.0.29)

  - scraper should not fail on invalid URL (0.0.28)

  - bug with reading in taxonomy lines (0.0.27)

  - bug in github parser (0.0.26)

  - refactoring interface to have one column table (0.0.24)

  - streamline data export to included minimal repo data (0.0.23)

  - static search interface and delay parameter for scrape (0.0.22)

  - ensuring that interface generation uses constent colors (0.0.21)

  - bug that taxonomy needs newline for export (0.0.2)

  - adding analysis metrics (0.0.19)

  - bugfix to export json api including url prefix 0.0.18)

  - static annotation export to GitHub issues (0.0.17)

  - allowing Zenodo parser to hand off to GitLab or GitHub (0.0.16)

  - adding import of static issue (markdown) files for annotation (0.0.15)

  - adding generation of data.json to static site export (0.0.14)

  - web interface needs software (or other custom) prefix for export (0.0.13)

  - Adding export of flask for static interface (0.0.12)

  - Updating beautiful soup to use html.parser (0.0.11)

  - first draft including database backends and GitHub parser (0.0.1)

  - skeleton release (0.0.0)